%global octpkg optim

Name:           octave-%{octpkg}
Version:        1.4.1
Release:        1%{?dist}
Summary:        A non-linear optimization tool kit for Octave
Group:          Applications/Engineering
# C++ and .m are GPLv3+, documentation is GFDL
License:        GPLv3+ and GFDL
URL:            http://octave.sourceforge.net/optim/
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
# avoid stripping binaries to get useful debuginfo packages
# fedora specific - not upstreamed
Patch0:         %{name}-nostrip.patch
Patch1:         %{name}-retval.patch

BuildRequires:  octave-devel
BuildRequires:  octave-struct >= 1.0.10
BuildRequires:  octave-parallel
BuildRequires:  tex(latex)
BuildRequires:  tex(dsfont.sty)
BuildRequires:  ghostscript
# for arm
BuildRequires:  blas-devel
BuildRequires:  lapack-devel

Requires:       octave(api) = %{octave_api}
Requires(post): octave
Requires(postun): octave
Requires:       octave-struct >= 1.0.10


%description
This package contains a non-linear optimization tool kit for Octave, containing
functions for curve fitting and the following minimization algorithms:
* Nead-Miller simplex
* Conjugate Gradients
* Memory limited BFGS
* Simulated Annealing

%prep
%setup -q -n %{octpkg}-%{version}
%patch0 -p0 -b .nostrip
TS=$(date -r src/samin.cc  +%%Y%%m%%d%%H%%M.%%S)
%patch1 -p1 -b .retval
touch -t ${TS} src/samin.cc

%build
#octave pkg build dependency check does not work
#https://bugzilla.redhat.com/show_bug.cgi?id=733615
#octave_pkg_build
%octave_cmd pkg build '-verbose' '-nodeps' %{_tmppath}/%{name}-%{version}-%{release}.%{_arch} %{_builddir}/%{buildsubdir}
make -C doc DVIPDF=dvipdf optim-mini-howto-2.pdf

%install
%octave_pkg_install
rm -rf %{buildroot}/%{octpkgdir}/doc/.svnignore
chmod a-x %{buildroot}/%{octpkgdir}/*.m
rm -rf  %{buildroot}/%{octpkgdir}/doc

%post
%octave_cmd pkg rebuild

%preun
%octave_pkg_preun

%postun
%octave_cmd pkg rebuild

%files
%dir %{octpkgdir}
%doc %{octpkgdir}/doc-cache
%{octpkgdir}/*.m
%{octpkgdir}/packinfo
%doc %{octpkgdir}/packinfo/COPYING
%{octpkglibdir}
%{octpkgdir}/PKG_ADD
%{octpkgdir}/private/optim_problems_p_r_y.data
%{octpkgdir}/private/*.m

%doc doc/optim-mini-howto-2.pdf doc/development/interfaces.txt

%changelog
* Tue Jul 07 2015 Orion Poplawski <orion@cora.nwra.com> - 1.4.1-1
- Update to 1.4.1

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.4.0-3
- Rebuilt for GCC 5 C++11 ABI change

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 01 2014 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.4.0-1
- update to 1.4.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Jan 10 2014 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.3.0-1
- update to 1.3.0

* Sun Dec 29 2013 Orion Poplawski <orion@cora.nwra.com> - 1.2.2-5
- Rebuild for octave 3.8.0

* Thu Sep 26 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.2.2-4
- rebuild for blas and atlas

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Nov  6 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.2.2-1
- update to 1.2.2

* Sun Sep 16 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.2.1-1
- update to 1.2.1

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 12 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.2.0-1
- update to 1.2.0

* Tue Jun  5 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.1.0-1
- update to 1.1.0

* Mon Jan 16 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.0.17-3
- rebuild for octave 3.6.0

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.17-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Nov 28 2011 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.0.17-1
- update to 1.0.17

* Fri Aug 26 2011 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.0.16-3
- compile tex docs into a pdf file instead of shipping tex sources

* Wed Aug 24 2011 Thomas Sailer <t.sailer@alumni.ethz.ch> - 1.0.16-2
- review input

* Fri Jun 03 2011 Thomas Sailer <t.sailer@alumni.ethz.ch> 1.0.16-1
- initial package for Fedora
